@@ -93,11 +93,11 @@ setMethod("join_features", "SingleCellExperiment", function(.data,
     }
 })
 
+#' @name tidy
+#' @rdname tidy
 #' @title (DEPRECATED) tidy for `SingleCellExperiment`
-#' @name tidy.SingleCellExperiment
 #'
-#' @param x A `SingleCellExperiment` object.
-#' @param ... Additional arguments passed to `generics::tidy`. (Unused.)
+#' @param object A `SingleCellExperiment` object.
 #' @return A `tidySingleCellExperiment` object. (DEPRECATED - not needed anymore)
 #'
 #' @examples
@@ -107,10 +107,15 @@ setMethod("join_features", "SingleCellExperiment", function(.data,
 #' @references
 #' Hutchison, W.J., Keyes, T.J., The tidyomics Consortium. et al. The tidyomics ecosystem: enhancing omic data analyses. Nat Methods 21, 1166–1170 (2024). https://doi.org/10.1038/s41592-024-02299-2
 #'
-#' @importFrom generics tidy
+#' @export
+tidy <- function(object) {
+    UseMethod("tidy", object)
+}
+
+#' @rdname tidy
 #' @importFrom lifecycle deprecate_warn
 #' @export
-tidy.SingleCellExperiment <- function(x, ...) {
+tidy.SingleCellExperiment <- function(object) {
 
     # DEPRECATE
     deprecate_warn(
@@ -118,7 +123,7 @@ tidy.SingleCellExperiment <- function(x, ...) {
         what="tidy()",
         details="tidySingleCellExperiment says: tidy() is not needed anymore.")
 
-    return(x)
+    return(object)
 }
 
 #' @name aggregate_cells
@@ -157,6 +162,7 @@ tidy.SingleCellExperiment <- function(x, ...) {
 #' @importFrom methods as
 #'
 #'
+#' @export
 setMethod("aggregate_cells", "SingleCellExperiment", function(.data,
     .sample=NULL, slot="data", assays=NULL,
     aggregation_function=Matrix::rowSums,
